pub enum Target {
Head,
Branch(String),
Tag(String),
Commit(ObjectId),
}Expand description
The different kinds of git “thing” that we can target.
Variants
Head
By default, we target the remote HEAD.
Branch(String)
Target the tip of a specific branch.
Tag(String)
Target a specific tag.
Commit(ObjectId)
Target a specific commit.
Currently, we only support a full commit: this needs to be a full hex-encoded
sha hash. We could try to support prefixes also, but it requires some work
and it appears to be inherently less efficient because there doesn’t seem
to be a way to fetch it in one shot. At least, when cargo needs to fetch an
abbreviated hash it fetches everything and then looks for the hash among the
things that it finds.