A small crate providing a convienient interface to the git operations that nickel uses.
Structs
- Spec
- Specifies a git location that we can fetch.
Enums
- Error
- An error that occurred during a git operation.
- Target
- The different kinds of git “thing” that we can target.
Functions
- fetch
- Fetches the contents of a git repository into directory.